@@ -1,5 +1,17 @@
-#!/usr/bin/env runhaskell
-{-# LANGUAGE RecordWildCards, NamedFieldPuns #-}
+{-# LANGUAGE CPP, RecordWildCards, NamedFieldPuns #-}
+
+#ifndef MIN_VERSION_Cabal
+#define MIN_VERSION_Cabal(x,y,z) 0
+#endif
+
+#if MIN_VERSION_Cabal(2,0,0)
+
+-- https://github.com/haskell/cabal/pull/4501 is upstream in 2.0, yey
+import Distribution.Simple
+main = defaultMain
+
+#else
+
 import Distribution.Simple
 import Distribution.Simple.Utils
 import Distribution.Simple.Setup
@@ -11,18 +23,10 @@ import Distribution.Simple.LocalBuildInfo
 import Distribution.Simple.Program
 import Distribution.PackageDescription
 
-import qualified Data.Map as M
-import Data.Map (Map)
-
-import Control.Arrow
-import Control.Applicative
+import Control.Applicative -- for GHC<7.10
 import Control.Monad
 import Data.List
 import Data.Maybe
-import Data.Version
-import Data.Monoid
-import System.Process
-import System.Exit
 import System.FilePath
 import System.Directory (renameFile)
 
@@ -70,7 +74,7 @@ xInstallTarget :: PackageDescription
                -> (PackageDescription -> LocalBuildInfo -> IO ())
                -> IO ()
 xInstallTarget pd lbi cf fn = do
-  let (extended, regular) = partition isInternal (executables pd)
+  let (extended, regular) = partition isExeScopePrivate (executables pd)
 
   let pd_regular = pd { executables = regular }
 
@@ -96,13 +100,16 @@ xInstallTarget pd lbi cf fn = do
 
   fn pd_regular lbi
 
+isExeScopePrivate :: Executable -> Bool
+isExeScopePrivate exe =
+  fromMaybe False $ (=="private") <$> lookup "x-scope" fields
  where
-   isInternal :: Executable -> Bool
-   isInternal exe =
-    fromMaybe False $ (=="True") <$> lookup "x-internal" (customFieldsBI $ buildInfo exe)
+   fields = customFieldsBI $ buildInfo exe
 
 onlyExePackageDesc :: [Executable] -> PackageDescription -> PackageDescription
 onlyExePackageDesc exes pd = emptyPackageDescription {
                      package = package pd
                    , executables = exes
                    }
+
+#endif
